package
Version:
v0.0.26
Opens a new window with list of versions in this module.
Published: Jun 9, 2025
License: Unlicense
Opens a new window with license information.
Imports: 21
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type FileInfo struct {
Name string `json:"file_name"`
Size int `json:"file_size"`
Metadata *storage.Metadata `json:"metadata"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.